==> material__line-ripple-4.0.0.jar: META-INF/resources/webjars/material__line-ripple/4.0.0/foundation.d.ts <==
/**
 * @license
 * Copyright 2018 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
import { MDCFoundation } from '@material/base/foundation';
import { MDCLineRippleAdapter } from './adapter';
export declare class MDCLineRippleFoundation extends MDCFoundation<MDCLineRippleAdapter> {
    static readonly cssClasses: {
        LINE_RIPPLE_ACTIVE: string;
        LINE_RIPPLE_DEACTIVATING: string;
    };
    /**
     * See {@link MDCLineRippleAdapter} for typing information on parameters and return types.
     */
    static readonly defaultAdapter: MDCLineRippleAdapter;
    private readonly transitionEndHandler_;
    constructor(adapter?: Partial<MDCLineRippleAdapter>);
    init(): void;
    destroy(): void;
    activate(): void;
    setRippleCenter(xCoordinate: number): void;
    deactivate(): void;
    handleTransitionEnd(evt: TransitionEvent): void;
}
export default MDCLineRippleFoundation;

==> material__line-ripple-11.0.0.jar: META-INF/resources/webjars/material__line-ripple/11.0.0/foundation.d.ts <==
/**
 * @license
 * Copyright 2018 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
import { MDCFoundation } from '@material/base/foundation';
import { MDCLineRippleAdapter } from './adapter';
export declare class MDCLineRippleFoundation extends MDCFoundation<MDCLineRippleAdapter> {
    static get cssClasses(): {
        LINE_RIPPLE_ACTIVE: string;
        LINE_RIPPLE_DEACTIVATING: string;
    };
    /**
     * See {@link MDCLineRippleAdapter} for typing information on parameters and return types.
     */
    static get defaultAdapter(): MDCLineRippleAdapter;
    private readonly transitionEndHandler_;
    constructor(adapter?: Partial<MDCLineRippleAdapter>);
    init(): void;
    destroy(): void;
    activate(): void;
    setRippleCenter(xCoordinate: number): void;
    deactivate(): void;
    handleTransitionEnd(evt: TransitionEvent): void;
}
export default MDCLineRippleFoundation;
